#
# spec file for package firehol
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           firehol
Version:        3.1.8
Release:        1.1
Summary:        Tools to build stateful firewalls and traffic shaping
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
URL:            https://firehol.org/
Source:         https://github.com/firehol/firehol/releases/download/v%{version}/firehol-%{version}.tar.xz
Source99:       %{name}-rpmlintrc
Patch0:         harden_firehol.service.patch
Patch1:         harden_fireqos.service.patch
BuildRequires:  curl
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  iprange
BuildRequires:  iproute2
BuildRequires:  ipset
BuildRequires:  iptables
BuildRequires:  iputils
BuildRequires:  jq
BuildRequires:  kmod-compat
BuildRequires:  less
BuildRequires:  ncurses-utils
BuildRequires:  nfacct
BuildRequires:  pkgconfig
BuildRequires:  procps
BuildRequires:  screen
BuildRequires:  tcpdump
BuildRequires:  traceroute
BuildRequires:  unzip
BuildRequires:  util-linux-systemd
BuildRequires:  wget
BuildRequires:  whois
BuildRequires:  pkgconfig(systemd)
Requires:       curl
Requires:       iprange
Requires:       iproute2
Requires:       ipset
Requires:       iptables
Requires:       iputils
Requires:       kmod-compat
Requires:       nfacct
Requires:       procps
Requires:       screen
Requires:       tcpdump
Requires:       traceroute
Requires:       util-linux-systemd
Recommends:     git-core
Recommends:     jq
Recommends:     less
Recommends:     ncurses-utils
Recommends:     unzip
Recommends:     wget
Recommends:     whois
BuildArch:      noarch

%description
FireHOL is a language (and a program to run it) which builds stateful firewalls
from human-readable configuration files.

FireQOS is a program which sets up traffic shaping from human-readable
configuration files.

Both programs abstract away the differences between IPv4 and IPv6, and rules
for each protocol can be applied as needed.

%package doc
Summary:        FireHOL documentation
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Contains documentation and configuration examples for FireHOL.

%prep
%autosetup -p1

%build
%configure --docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
install -d %{buildroot}%{_unitdir}

cp %{buildroot}%{_docdir}/%{name}/contrib/*.service %{buildroot}%{_unitdir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcfirehol
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcfireqos

chmod -Rv o= %{buildroot}%{_sysconfdir}/firehol/

%fdupes -s %{buildroot}%{_mandir}

%pre
%service_add_pre firehol.service fireqos.service

%preun
%service_del_preun firehol.service fireqos.service

%post
%service_add_post firehol.service fireqos.service

%postun
%service_del_postun firehol.service fireqos.service

%files
%config(noreplace) %{_sysconfdir}/firehol/
%{_sbindir}/firehol
%{_sbindir}/fireqos
%{_sbindir}/link-balancer
%{_sbindir}/update-ipsets
%{_sbindir}/vnetbuild
%{_libexecdir}/firehol/
%{_datadir}/update-ipsets/
%{_sbindir}/rcfirehol
%{_sbindir}/rcfireqos
%{_unitdir}/fire*service

%files doc
%doc ChangeLog README THANKS
%license COPYING
%{_docdir}/%{name}
%{_mandir}/man1/firehol.1%{?ext_man}
%{_mandir}/man1/fireqos.1%{?ext_man}
%{_mandir}/man1/vnetbuild.1%{?ext_man}
%{_mandir}/man5/firehol*.5%{?ext_man}
%{_mandir}/man5/fireqos*.5%{?ext_man}
%{_mandir}/man5/vnetbuild*.5%{?ext_man}

%changelog
* Sat Mar 15 2025 Mia Herkt <mia@0x0.st>
- firehol (3.1.8) - 2025-03-15
  * Update-Ipsets
  - Remove some dead lists
  - Handle ipsets temporarily locked by another process with
    retries
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Sep 14 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_firehol.service.patch
  * harden_fireqos.service.patch
* Thu Dec 31 2020 Mia Herkt <mia@0x0.st>
- firehol (3.1.7) - 2020-12-31
  * FireHOL
  - Fix dhcpv6 example to say dhcpv6 #438
  - blacklist - add "nolog" option
  - blacklist - reject with tcp-reset for outbound TCP connections
  - firehol.service - Use `firehol start` for  ExecReload=
  - Don't drop icmpv6 rules with FIREHOL_RULESET_MODE optimal #372
  * FireQos
  - workaround for cases where "-ifb" name gets truncated
* Mon Aug 13 2018 9+suse@cirno.systems
- Drop useless _service
  firehol (3.1.6) - 2018-08-13
  * FireHOL
  - Boot startup fix #260
  - docker_bridge helper #114
  - Allow newer iptables #264
  - Log blocked/dropped packets in synproxy, mac, connlimit, fragments, ...
  - Fix wait for netfilter ready when using namespaces
  - Fast activation fixes #272
  - Allow matching DSCP CS0; fixes #288
  - Allow DROP_INVALID with any action (e.g. REJECT)
  - Add option FIREHOL_ACCEPT_OUTPUT_UNMATCHED_TCP_RST
  * FireQOS
  - Fix status to works with newer iproute; fixes #317
  * Link-Balancer
  - linkdown: routes cannot be added or deleted whilst marked invalid #211
  * Update-Ipsets
  - Various fixes, including #266 #265
  - List additions, updates and removals
  - Minor enhancements
* Sun Sep 17 2017 9@cirno.systems
  firehol (3.1.5) - 2017-09-17
  * FireHOL
  - Fix some links in documentation
  * FireQOS
  - Insert a rawmark mask if none specified
  * Update-Ipsets
  - Support serving ipset files from local web server
  - Lower pressure on github
* Sun Aug 20 2017 9@cirno.systems
  firehol (3.1.4) - 2017-08-20
  * FireHOL
  - Google hangouts port range fix #235
  - Fix hashlimit option names #223
  - Documentation improvements, marks #184 and cthelper #94
  - Allow negating interface in blacklist #143
  * FireQOS
  - DSCP match fixes #248
  - TCP match fix #249
  - Improve docs on using act_connmark to match ingress marked traffic #231
  * Update-Ipsets
  - Added various lists, removed discontinued ones
  - Include URL in user agent string in #217
  - Relax umask to allow stats collection by netdata #221
* Sun Jul  9 2017 jengelh@inai.de
- Avoid duplicate expansion of %%service_*
- firehol-doc subpackage ought to be noarch
* Wed Mar 29 2017 9@cirno.systems
  firehol (3.1.3) - 2017-02-17
  * FireHOL
  - Be more strict when detecting address ranges
    Fixes #199 where hostnames such as x-2.example.com are incorrectly
    identified as ranges.
  * Common
  - Create relative links to binaries, which prevents errors when
    installing with DESTDIR other than /
    Fix for #178 and #201 proposed by @kneeke
  firehol (3.1.2) - 2017-02-05
  * FireHOL
  - Include user policies in chains before handling orphans. Fixes NFS
    client where FIREHOL_DROP_ORPHAN_TCP_* options are in force.
  - Do not allow server/client statements without any effect on the
    firewall; #193
  - Saved firewall contents made reproducible by always zeroing counters
    and removing the dates from comments
  * FireQOS
  - Example had an ambiguous shebang which has been removed
  * Common
  - Running "make check" now exits non-zero if a test failed or none ran
  - Various copyright updates
  - Fixed pull requests from external repositories; these would previously
    fail to build on Travis
* Thu Feb  2 2017 9@cirno.systems
- 3.1.1
